@@ -45,16 +45,72 @@ aictab.AICaov.lm <-
 
     ##check if some models are redundant
     if(length(unique(Results$AICc)) != length(cand.set)) warning("\nCheck model structure carefully as some models may be redundant\n")
-         
+
+    
     ##extract LL
     Results$LL <- unlist(lapply(X = cand.set, FUN = function(i) logLik(i)[1]))
-        
+
     ##rename correctly to AIC
     if(second.ord == FALSE) {
-      colnames(Results) <- c("Modnames", "K", "AIC", "Delta_AIC", "ModelLik", "AICWt")
+      colnames(Results)[1:6] <- c("Modnames", "K", "AIC", "Delta_AIC", "ModelLik", "AICWt")
+    }
+
+    
+    if(sort)  {
+      Results <- Results[rev(order(Results[, 6])),] 	  #if sort=TRUE, models are ranked based on Akaike weights
+      Results$Cum.Wt <- cumsum(Results[, 6])                        #display cumulative sum of Akaike weights
+    } else {Results$Cum.Wt <- NULL}
+
+    
+    class(Results) <- c("aictab", "data.frame")
+    return(Results)
+  }
+
+
+
+##aov
+aictab.AICbetareg <-
+  function(cand.set, modnames = NULL, second.ord = TRUE, nobs = NULL, sort = TRUE, ...){
+
+    ##check if named list if modnames are not supplied
+    if(is.null(modnames)) {
+      if(is.null(names(cand.set))) {
+        modnames <- paste("Mod", 1:length(cand.set), sep = "")
+        warning("\nModel names have been supplied automatically in the table\n")
+      } else {
+        modnames <- names(cand.set)
+      }
+    }
+      
+
+    ##add check to see whether response variable is the same for all models
+    check.resp <- lapply(X = cand.set, FUN = function(b) formula(b)[2])
+    if(length(unique(check.resp)) > 1) stop("\nYou must use the same response variable for all models\n")
+
+    Results <- NULL
+    Results <- data.frame(Modnames = modnames)                    #assign model names to first column
+    Results$K <- unlist(lapply(X = cand.set, FUN = AICc, return.K = TRUE,
+                               second.ord = second.ord, nobs = nobs))     #extract number of parameters
+    Results$AICc <- unlist(lapply(X = cand.set, FUN = AICc, return.K = FALSE, 
+                                  second.ord = second.ord, nobs = nobs))  #extract AICc                                      #
+    Results$Delta_AICc <- Results$AICc - min(Results$AICc)            #compute delta AICc
+    Results$ModelLik <- exp(-0.5*Results$Delta_AICc)                #compute model likelihood required to compute Akaike weights
+    Results$AICcWt <- Results$ModelLik/sum(Results$ModelLik)        #compute Akaike weights
+
+    ##check if some models are redundant
+    if(length(unique(Results$AICc)) != length(cand.set)) warning("\nCheck model structure carefully as some models may be redundant\n")
+         
+
+    ##extract LL
+    Results$LL <- unlist(lapply(X = cand.set, FUN = function(i) logLik(i)[1]))
+
+    
+    ##rename correctly to AIC
+    if(second.ord == FALSE) {
+      colnames(Results)[1:6] <- c("Modnames", "K", "AIC", "Delta_AIC", "ModelLik", "AICWt")
     }  
 
-      
+                
     if(sort)  {
       Results <- Results[rev(order(Results[, 6])),] 	  #if sort=TRUE, models are ranked based on Akaike weights
       Results$Cum.Wt <- cumsum(Results[, 6])                        #display cumulative sum of Akaike weights
@@ -329,6 +385,8 @@ aictab.AICglm.lm <-
   }
 
 
+
+##gls
 aictab.AICgls <-
   function(cand.set, modnames = NULL, second.ord = TRUE, nobs = NULL, sort = TRUE, ...){  #specify whether table should be sorted or not by delta AICc
 
@@ -398,6 +456,98 @@ aictab.AICgls <-
 
 
 
+##nls
+aictab.AICgnls.gls <-
+  function(cand.set, modnames = NULL, second.ord = TRUE, nobs = NULL, sort = TRUE, ...){  #specify whether table should be sorted or not by delta AICc
+
+    ##check if named list if modnames are not supplied
+    if(is.null(modnames)) {
+      if(is.null(names(cand.set))) {
+        modnames <- paste("Mod", 1:length(cand.set), sep = "")
+        warning("\nModel names have been supplied automatically in the table\n")
+      } else {
+        modnames <- names(cand.set)
+      }
+    }
+    
+    ##add check to see whether response variable is the same for all models
+    check.resp <- lapply(X = cand.set, FUN = function(b) formula(b)[2])
+    if(length(unique(check.resp)) > 1) stop("\nYou must use the same response variable for all models\n")
+       
+    Results <- data.frame(Modnames=modnames)                    #assign model names to first column
+    Results$K <- unlist(lapply(cand.set, AICc, return.K = TRUE, second.ord = second.ord, nobs = nobs))     #extract number of parameters
+    Results$AICc <- unlist(lapply(cand.set, AICc, return.K = FALSE, second.ord = second.ord, nobs = nobs))  #extract AICc                                      #
+    Results$Delta_AICc <- Results$AICc - min(Results$AICc)            #compute delta AICc
+    Results$ModelLik <- exp(-0.5*Results$Delta_AICc)                #compute model likelihood required to compute Akaike weights
+    Results$AICcWt <- Results$ModelLik/sum(Results$ModelLik)        #compute Akaike weights
+    Results$LL <- unlist(lapply(X = cand.set, FUN = function(i) logLik(i)[1]))
+    
+    ##check if some models are redundant
+    if(length(unique(Results$AICc)) != length(cand.set)) warning("\nCheck model structure carefully as some models may be redundant\n")
+    
+    ##rename correctly to AIC
+    if(second.ord == FALSE) {
+      colnames(Results)[1:6] <- c("Modnames", "K", "AIC", "Delta_AIC", "ModelLik", "AICWt")
+    }
+
+    if(sort)  {
+      Results <- Results[rev(order(Results[, 6])),] 	  #if sort=TRUE, models are ranked based on Akaike weights
+      Results$Cum.Wt <- cumsum(Results[, 6])                        #display cumulative sum of Akaike weights
+    } else {Results$Cum.Wt <- NULL}
+   
+    
+    class(Results) <- c("aictab", "data.frame")
+    return(Results)
+  }
+
+
+
+##hurdle
+aictab.AIChurdle <-
+  function(cand.set, modnames = NULL, second.ord = TRUE, nobs = NULL, sort = TRUE, ...){  #specify whether table should be sorted or not by delta AICc
+
+    ##check if named list if modnames are not supplied
+    if(is.null(modnames)) {
+      if(is.null(names(cand.set))) {
+        modnames <- paste("Mod", 1:length(cand.set), sep = "")
+        warning("\nModel names have been supplied automatically in the table\n")
+      } else {
+        modnames <- names(cand.set)
+      }
+    }
+    
+    #if(c.hat != 1) stop("\nThis function does not support overdispersion in \'zeroinfl\' models\n")
+    
+    ##add check to see whether response variable is the same for all models
+    check.resp <- lapply(X = cand.set, FUN = function(b) formula(b)[2])                                        
+    if(length(unique(check.resp)) > 1) stop("\nYou must use the same data set for all models\n")
+       
+    Results <- data.frame(Modnames = modnames)                    #assign model names to first column
+    Results$K <- unlist(lapply(cand.set, AICc, return.K = TRUE, second.ord = second.ord, nobs = nobs))     #extract number of parameters
+    Results$AICc <- unlist(lapply(cand.set, AICc, return.K = FALSE, second.ord = second.ord, nobs = nobs))  #extract AICc                                      #
+    Results$Delta_AICc <- Results$AICc - min(Results$AICc)            #compute delta AICc
+    Results$ModelLik <- exp(-0.5*Results$Delta_AICc)                #compute model likelihood required to compute Akaike weights
+    Results$AICcWt <- Results$ModelLik/sum(Results$ModelLik)        #compute Akaike weights
+
+   ##check if some models are redundant
+    if(length(unique(Results$AICc)) != length(cand.set)) warning("\nCheck model structure carefully as some models may be redundant\n")
+    
+    Results$LL <- unlist(lapply(X= cand.set, FUN = function(i) logLik(i)))      
+
+    ##rename correctly to AIC
+    if(second.ord == FALSE) {
+      colnames(Results)[1:6] <- c("Modnames", "K", "AIC", "Delta_AIC", "ModelLik", "AICWt")
+    }
+
+    if(sort)  {
+      Results <- Results[rev(order(Results[, 6])),] 	  #if sort=TRUE, models are ranked based on Akaike weights
+      Results$Cum.Wt <- cumsum(Results[, 6])                        #display cumulative sum of Akaike weights
+    } else {Results$Cum.Wt <- NULL}
+   
+    
+    class(Results) <- c("aictab", "data.frame")
+    return(Results)
+  }
 
 
 
@@ -435,13 +585,13 @@ aictab.AIClm <-
          
     ##extract LL
     Results$LL <- unlist(lapply(X = cand.set, FUN = function(i) logLik(i)[1]))
-        
+
     ##rename correctly to AIC
     if(second.ord == FALSE) {
-      colnames(Results) <- c("Modnames", "K", "AIC", "Delta_AIC", "ModelLik", "AICWt")
+      colnames(Results)[1:6] <- c("Modnames", "K", "AIC", "Delta_AIC", "ModelLik", "AICWt")
     }  
 
-      
+
     if(sort)  {
       Results <- Results[rev(order(Results[, 6])),] 	  #if sort=TRUE, models are ranked based on Akaike weights
       Results$Cum.Wt <- cumsum(Results[, 6])                        #display cumulative sum of Akaike weights
@@ -838,7 +988,7 @@ aictab.AICglmerMod <-
 
 
 ##nlme
-aictab.AICnlme <-
+aictab.AICnlme.lme <-
   function(cand.set, modnames = NULL, second.ord = TRUE, nobs = NULL, sort = TRUE, ...){  #specify whether table should be sorted or not by delta AICc
 
     ##check if named list if modnames are not supplied
@@ -1247,6 +1397,59 @@ aictab.AICrlm.lm <-
 
 
 
+##survreg
+aictab.AICsurvreg <-
+  function(cand.set, modnames = NULL, second.ord = TRUE, nobs = NULL, sort = TRUE, ...){
+
+    ##check if named list if modnames are not supplied
+    if(is.null(modnames)) {
+      if(is.null(names(cand.set))) {
+        modnames <- paste("Mod", 1:length(cand.set), sep = "")
+        warning("\nModel names have been supplied automatically in the table\n")
+      } else {
+        modnames <- names(cand.set)
+      }
+    }
+      
+
+    ##add check to see whether response variable is the same for all models
+    check.resp <- lapply(X = cand.set, FUN = function(b) formula(b)[2])
+    if(length(unique(check.resp)) > 1) stop("\nYou must use the same response variable for all models\n")
+
+    Results <- NULL
+    Results <- data.frame(Modnames = modnames)                    #assign model names to first column
+    Results$K <- unlist(lapply(X = cand.set, FUN = AICc, return.K = TRUE,
+                               second.ord = second.ord, nobs = nobs))     #extract number of parameters
+    Results$AICc <- unlist(lapply(X = cand.set, FUN = AICc, return.K = FALSE, 
+                                  second.ord = second.ord, nobs = nobs))  #extract AICc                                      #
+    Results$Delta_AICc <- Results$AICc - min(Results$AICc)            #compute delta AICc
+    Results$ModelLik <- exp(-0.5*Results$Delta_AICc)                #compute model likelihood required to compute Akaike weights
+    Results$AICcWt <- Results$ModelLik/sum(Results$ModelLik)        #compute Akaike weights
+
+    ##check if some models are redundant
+    if(length(unique(Results$AICc)) != length(cand.set)) warning("\nCheck model structure carefully as some models may be redundant\n")
+         
+    ##extract LL
+    Results$LL <- unlist(lapply(X = cand.set, FUN = function(i) logLik(i)[1]))
+        
+    ##rename correctly to AIC
+    if(second.ord == FALSE) {
+      colnames(Results)[1:6] <- c("Modnames", "K", "AIC", "Delta_AIC", "ModelLik", "AICWt")
+    }  
+
+      
+    if(sort)  {
+      Results <- Results[rev(order(Results[, 6])),] 	  #if sort=TRUE, models are ranked based on Akaike weights
+      Results$Cum.Wt <- cumsum(Results[, 6])                        #display cumulative sum of Akaike weights
+    } else {Results$Cum.Wt <- NULL}
+
+    
+    class(Results) <- c("aictab", "data.frame")
+    return(Results)
+  }
+
+
+
 ##occu
 aictab.AICunmarkedFitOccu <- function(cand.set, modnames = NULL, second.ord = TRUE, nobs = NULL, sort = TRUE, c.hat = 1, ...){  #specify whether table should be sorted or not by delta AICc
 
@@ -1413,7 +1616,7 @@ aictab.AICunmarkedFitOccuRN <- function(cand.set, modnames = NULL, second.ord =
 
   ##rename correctly to AIC
   if(second.ord == FALSE) {
-    colnames(Results)<-c("Modnames", "K", "AIC", "Delta_AIC", "ModelLik", "AICWt")
+    colnames(Results)[1:6] <- c("Modnames", "K", "AIC", "Delta_AIC", "ModelLik", "AICWt")
   }  
   
   if(sort)  {
@@ -1586,7 +1789,7 @@ aictab.AICunmarkedFitDS <- function(cand.set, modnames = NULL, second.ord = TRUE
 
   ##rename correctly to AIC
   if(second.ord == FALSE) {
-    colnames(Results)<-c("Modnames", "K", "AIC", "Delta_AIC", "ModelLik", "AICWt")
+    colnames(Results)[1:6] <- c("Modnames", "K", "AIC", "Delta_AIC", "ModelLik", "AICWt")
   }  
     
   if(sort)  {
@@ -1635,7 +1838,7 @@ aictab.AICunmarkedFitGDS <- function(cand.set, modnames = NULL, second.ord = TRU
 
   ##rename correctly to AIC
   if(second.ord == FALSE) {
-    colnames(Results)<-c("Modnames", "K", "AIC", "Delta_AIC", "ModelLik", "AICWt")
+    colnames(Results)[1:6] <- c("Modnames", "K", "AIC", "Delta_AIC", "ModelLik", "AICWt")
   }
   
   if(sort)  {
@@ -1681,7 +1884,7 @@ aictab.AICunmarkedFitOccuFP <- function(cand.set, modnames = NULL, second.ord =
     
   ##rename correctly to AIC
   if(second.ord == FALSE) {
-    colnames(Results)<-c("Modnames", "K", "AIC", "Delta_AIC", "ModelLik", "AICWt")
+    colnames(Results)[1:6] <- c("Modnames", "K", "AIC", "Delta_AIC", "ModelLik", "AICWt")
   }  
   
   if(sort)  {
@@ -1726,7 +1929,7 @@ aictab.AICunmarkedFitMPois <- function(cand.set, modnames = NULL, second.ord = T
     
   ##rename correctly to AIC
   if(second.ord == FALSE) {
-    colnames(Results)<-c("Modnames", "K", "AIC", "Delta_AIC", "ModelLik", "AICWt")
+    colnames(Results)[1:6] <- c("Modnames", "K", "AIC", "Delta_AIC", "ModelLik", "AICWt")
   }
   
 
@@ -1773,7 +1976,7 @@ aictab.AICunmarkedFitGMM <- function(cand.set, modnames = NULL, second.ord = TRU
 
   ##rename correctly to AIC
   if(second.ord == FALSE) {
-    colnames(Results)<-c("Modnames", "K", "AIC", "Delta_AIC", "ModelLik", "AICWt")
+    colnames(Results)[1:6] <- c("Modnames", "K", "AIC", "Delta_AIC", "ModelLik", "AICWt")
   }  
   
   if(sort)  {
@@ -1819,7 +2022,7 @@ aictab.AICunmarkedFitGPC <- function(cand.set, modnames = NULL, second.ord = TRU
 
   ##rename correctly to AIC
   if(second.ord == FALSE) {
-    colnames(Results)<-c("Modnames", "K", "AIC", "Delta_AIC", "ModelLik", "AICWt")
+    colnames(Results)[1:6] <- c("Modnames", "K", "AIC", "Delta_AIC", "ModelLik", "AICWt")
   }  
   
   if(sort)  {
@@ -1851,6 +2054,7 @@ aictab.AICvglm <-
     check.resp <- lapply(X = cand.set, FUN = function(b) formula(b)[2])
     if(length(unique(check.resp)) > 1) stop("\nYou must use the same response variable for all models\n")
 
+    ##changed to AICcmodavg:::AICc.vglm to avoid conflicts with VGAM
     Results <- data.frame(Modnames=modnames)                    #assign model names to first column
     Results$K <- unlist(lapply(X = cand.set, FUN = AICc, return.K = TRUE, 
                                second.ord = second.ord, nobs = nobs, c.hat = c.hat))     #extract number of parameters
