@@ -86,6 +86,85 @@ importance.AICaov.lm <- function(cand.set, parm, modnames = NULL, second.ord = T
 
 
 
+##betareg
+importance.AICbetareg <- function(cand.set, parm, modnames = NULL, second.ord = TRUE, nobs = NULL, ...){
+
+  ##check if named list if modnames are not supplied
+    if(is.null(modnames)) {
+      if(is.null(names(cand.set))) {
+        modnames <- paste("Mod", 1:length(cand.set), sep = "")
+        warning("\nModel names have been supplied automatically in the table\n")
+      } else {
+        modnames <- names(cand.set)
+      }
+    }
+    
+    
+    ##remove all leading and trailing white space and within parm
+    parm <- gsub('[[:space:]]+', "", parm)
+
+    ##reverse parm
+    reversed.parm <- reverse.parm(parm)
+
+
+    ##extract labels
+    ##determine if parameter is on mean or phi
+    if(regexpr(pattern = "\\(phi\\)_", parm) == "-1") {
+      mod_formula <- lapply(cand.set, FUN=function(i) rownames(summary(i)$coefficients$mean))
+    } else {
+      ##replace parm
+      parm <- gsub(pattern = "\\(phi\\)_", "", parm)
+      mod_formula <- lapply(cand.set, FUN=function(i) rownames(summary(i)$coefficients$precision))
+    }
+
+    ##if (Intercept) is chosen assign (Int) - for compatibility
+    if(identical(parm, "(Intercept)")) parm <- "Int"
+
+
+    ##setup matrix to indicate presence of parm in the model
+    include <- matrix(NA, nrow=length(cand.set), ncol=1)
+
+    ##iterate over each formula in mod_formula list
+    for (i in 1:length(cand.set)) {
+      idents <- NULL
+      form <- mod_formula[[i]]
+
+      ##iterate over each element of formula[[i]] in list
+      if(is.null(reversed.parm)) {
+        for (j in 1:length(form)) {
+          idents[j] <- identical(paste(parm), form[j])
+        }
+      } else {
+        for (j in 1:length(form)) {
+          idents[j] <- identical(parm, form[j]) | identical(reversed.parm, form[j])
+        }
+      }
+    
+      include[i] <- ifelse(any(idents==1), 1, 0)
+    }
+
+    ##add a check to determine if include always == 0
+    if (sum(include)==0) {stop("\nParameter not found in any of the candidate models\n") }
+
+    new_table <- aictab(cand.set = cand.set, modnames = modnames, second.ord = second.ord, nobs = nobs,
+                        sort = FALSE)  
+
+    ##add a check to determine if the same number of models include and exlude parameter
+    if (length(which(include == 1)) != length(which(include != 1)) ) {
+      stop("\nImportance values are only meaningful when the number of models with and without parameter are equal\n")
+    }
+
+    w.plus <- sum(new_table[which(include == 1), 6]) #select models including a given parameter
+    w.minus <- 1 - w.plus
+    imp <- list("parm" = parm, "w.plus" = w.plus, "w.minus" = w.minus)
+
+  
+    class(imp) <- c("importance", "list")
+    return(imp)
+  }
+
+
+
 ##clm
 importance.AICsclm.clm <- function(cand.set, parm, modnames = NULL, second.ord = TRUE, nobs = NULL, ...){
 
@@ -669,6 +748,79 @@ importance.AICgls <- function(cand.set, parm, modnames = NULL, second.ord = TRUE
 
 
 
+##hurdle
+importance.AIChurdle <- function(cand.set, parm, modnames = NULL, second.ord = TRUE, nobs = NULL, ...){
+  
+  ##check if named list if modnames are not supplied
+    if(is.null(modnames)) {
+      if(is.null(names(cand.set))) {
+        modnames <- paste("Mod", 1:length(cand.set), sep = "")
+        warning("\nModel names have been supplied automatically in the table\n")
+      } else {
+        modnames <- names(cand.set)
+      }
+    }
+    
+    
+    ##remove all leading and trailing white space and within parm
+    parm <- gsub('[[:space:]]+', "", parm)
+
+    ##reverse parm
+    reversed.parm <- reverse.parm(parm)
+
+
+    ##extract labels
+    mod_formula <- lapply(cand.set, FUN=function(i) labels(coef(i)))
+
+
+    ##if (Intercept) is chosen assign (Int) - for compatibility
+    if(identical(parm, "(Intercept)")) parm <- "Int"
+
+
+    ##setup matrix to indicate presence of parm in the model
+    include <- matrix(NA, nrow=length(cand.set), ncol=1)
+
+    ##iterate over each formula in mod_formula list
+    for (i in 1:length(cand.set)) {
+      idents <- NULL
+      form <- mod_formula[[i]]
+
+      ##iterate over each element of formula[[i]] in list
+      if(is.null(reversed.parm)) {
+        for (j in 1:length(form)) {
+          idents[j] <- identical(paste(parm), form[j])
+        }
+      } else {
+        for (j in 1:length(form)) {
+          idents[j] <- identical(parm, form[j]) | identical(reversed.parm, form[j])
+        }
+      }
+    
+      include[i] <- ifelse(any(idents==1), 1, 0)
+    }
+
+    ##add a check to determine if include always == 0
+    if (sum(include)==0) {stop("\nParameter not found in any of the candidate models\n") }
+
+    new_table <- aictab(cand.set = cand.set, modnames = modnames, second.ord = second.ord, nobs = nobs,
+                        sort = FALSE)  
+
+    ##add a check to determine if the same number of models include and exlude parameter
+    if (length(which(include == 1)) != length(which(include != 1)) ) {
+      stop("\nImportance values are only meaningful when the number of models with and without parameter are equal\n")
+    }
+
+    w.plus <- sum(new_table[which(include == 1), 6]) #select models including a given parameter
+    w.minus <- 1 - w.plus
+    imp <- list("parm" = parm, "w.plus" = w.plus, "w.minus" = w.minus)
+
+  
+    class(imp) <- c("importance", "list")
+    return(imp)
+  }
+
+
+
 ##lm
 importance.AIClm <- function(cand.set, parm, modnames = NULL, second.ord = TRUE, nobs = NULL, ...){
 
@@ -1324,6 +1476,79 @@ importance.AICrlm.lm <- function(cand.set, parm, modnames = NULL, second.ord = T
 
 
 
+##survreg
+importance.AICsurvreg <- function(cand.set, parm, modnames = NULL, second.ord = TRUE, nobs = NULL, ...){
+
+  ##check if named list if modnames are not supplied
+    if(is.null(modnames)) {
+      if(is.null(names(cand.set))) {
+        modnames <- paste("Mod", 1:length(cand.set), sep = "")
+        warning("\nModel names have been supplied automatically in the table\n")
+      } else {
+        modnames <- names(cand.set)
+      }
+    }
+    
+    
+    ##remove all leading and trailing white space and within parm
+    parm <- gsub('[[:space:]]+', "", parm)
+
+    ##reverse parm
+    reversed.parm <- reverse.parm(parm)
+
+
+    ##extract labels
+    mod_formula <- lapply(cand.set, FUN=function(i) names(summary(i)$coefficients))
+
+
+    ##if (Intercept) is chosen assign (Int) - for compatibility
+    if(identical(parm, "(Intercept)")) parm <- "Int"
+
+
+    ##setup matrix to indicate presence of parm in the model
+    include <- matrix(NA, nrow=length(cand.set), ncol=1)
+
+    ##iterate over each formula in mod_formula list
+    for (i in 1:length(cand.set)) {
+      idents <- NULL
+      form <- mod_formula[[i]]
+
+      ##iterate over each element of formula[[i]] in list
+      if(is.null(reversed.parm)) {
+        for (j in 1:length(form)) {
+          idents[j] <- identical(paste(parm), form[j])
+        }
+      } else {
+        for (j in 1:length(form)) {
+          idents[j] <- identical(parm, form[j]) | identical(reversed.parm, form[j])
+        }
+      }
+    
+      include[i] <- ifelse(any(idents==1), 1, 0)
+    }
+
+    ##add a check to determine if include always == 0
+    if (sum(include)==0) {stop("\nParameter not found in any of the candidate models\n") }
+
+    new_table <- aictab(cand.set = cand.set, modnames = modnames, second.ord = second.ord, nobs = nobs,
+                        sort = FALSE)  
+
+    ##add a check to determine if the same number of models include and exlude parameter
+    if (length(which(include == 1)) != length(which(include != 1)) ) {
+      stop("\nImportance values are only meaningful when the number of models with and without parameter are equal\n")
+    }
+
+    w.plus <- sum(new_table[which(include == 1), 6]) #select models including a given parameter
+    w.minus <- 1 - w.plus
+    imp <- list("parm" = parm, "w.plus" = w.plus, "w.minus" = w.minus)
+
+  
+    class(imp) <- c("importance", "list")
+    return(imp)
+  }
+
+
+
 ##colext
 importance.AICunmarkedFitColExt <- function(cand.set, parm, modnames = NULL, second.ord = TRUE, nobs = NULL, c.hat = 1,
                                                parm.type = NULL, ...){
